@@ -99,6 +99,12 @@ function show_waiter(id, html, color, to_hide, hide_on_error, hide_on_silent_err
   overlay.style.position = "absolute";
   overlay.style.zIndex = 9999;
   overlay.classList.add("waiter-overlay");
+
+  if(id === null) {
+    overlay.classList.add("waiter-fullscreen");
+  } else {
+    overlay.classList.add("waiter-local");
+  }
   //overlay.style.animation = "expand .15s ease-in-out";
 
   // append overlay content in overlay
@@ -129,7 +135,7 @@ function hide_waiter(id){
   var overlay = dom.getElementsByClassName("waiter-overlay");
 
   if(overlay.length > 0){
-    //dom.style.animation = "shrink .15s ease-in-out";
+    overlay[0].style.opacity = '0';
     setTimeout(function(){
       try {
         dom.removeChild(overlay[0]);
@@ -138,7 +144,7 @@ function hide_waiter(id){
       } finally {
         Shiny.setInputValue(id + "_waiter_hidden", true, {priority: 'event'});
       }
-    }, 150)
+    }, 250)
   } else{
     console.log("no waiter on", id);
   }
@@ -196,3 +202,20 @@ $(document).on('shiny:error', function(event) {
     hide_waiter(event.name);
   }
 });
+
+window.addEventListener("resize", function(){
+  let waiters = document.getElementsByClassName("waiter-local");
+  let fs = document.getElementsByClassName("waiter-fullscreen");
+
+  for(waiter of waiters){
+    dim = get_offset(waiter.parentElement);
+    waiter.style.width = dim.width + 'px';
+    waiter.style.height = dim.height + 'px';
+  }
+
+  for(waiter of fs){
+    dim = get_offset(waiter.parentElement);
+    waiter.style.width = window.innerWidth + 'px';
+    waiter.style.height = window.innerHeight + 'px';
+  }
+});
